/*
 * This could be in another package, handlers, but golang tend to be simgle folder per concern
 */

package sampleapp

import (
	"encoding/json"
	"log"
	"net/http"
	"sampleapp/customersvc"

	"github.com/gorilla/mux"
)

//CustomerHandlers handlers related to customers
type CustomerHandlers struct {
	svc customersvc.Servicer
}

//GetCustomer gets a customer
func (ch *CustomerHandlers) GetCustomer(w http.ResponseWriter, r *http.Request) {
	vars := mux.Vars(r)

	id := vars["id"]

	cust, err := ch.svc.FetchByID(id) // This should be in userservice
	if err == customersvc.ErrNotFound {
		httpErr(w, http.StatusNotFound, "Not found")
		return
	}
	if err != nil {
		httpErr(w, http.StatusInternalServerError, "Error fetching customer", err)
		return
	}
	json.NewEncoder(w).Encode(cust)
}

//PostCustomer posts a customer from application/json content as body
func (ch *CustomerHandlers) PostCustomer(w http.ResponseWriter, r *http.Request) {
	//TODO: check things like json validation, etc
	log.Println("Post")
	defer r.Body.Close()

	cust := &customersvc.Customer{}
	json.NewDecoder(r.Body).Decode(&cust)

	if cust.Name == "" {
		httpErr(w, http.StatusBadRequest, "Missing name field")
		return
	}
	if len(cust.Phone) == 0 {
		httpErr(w, http.StatusBadRequest, "Missing a phone number")
		return
	}

	err := ch.svc.Store(cust)
	if err != nil {
		httpErr(w, http.StatusInternalServerError, "Error saving customer", err)
		return
	}
	json.NewEncoder(w).Encode(cust)

	log.Println("Received:", cust)
	//Store user from body
}
