package sampleapp

import (
	"encoding/json"
	"fmt"
	"log"
	"net/http"
)

// httpResponse helper
func httpErr(w http.ResponseWriter, code int, msg ...interface{}) {
	w.WriteHeader(code)

	ret := map[string]interface{}{
		"err": fmt.Sprintln(msg...),
	}
	json.NewEncoder(w).Encode(ret)
}

// -------------------
// GO http Handler  for writing logs
//
type LogWriter struct {
	http.ResponseWriter
	statusCode int
}

func (lh *LogWriter) WriteHeader(code int) {
	lh.statusCode = code
	lh.ResponseWriter.WriteHeader(code)
}

func LogHandler(next http.HandlerFunc) http.HandlerFunc {

	return func(w http.ResponseWriter, r *http.Request) {
		lh := &LogWriter{w, 200} // Default 200
		if next != nil {
			next(lh, r)
		}
		log.Printf("%s (%d) - %s", r.Method, lh.statusCode, r.URL.Path)
	}
}
